@@ -13,7 +13,7 @@ use vars qw($VERSION $Debug);
 ######################################################################
 #### Configuration Section
 
-$VERSION = '3.470';
+$VERSION = '3.472';
 
 #######################################################################
 # CONSTRUCTORS
@@ -378,9 +378,9 @@ write back.  Often the callback will simply perform a search and replace.
 
 =head1 DISTRIBUTION
 
-Verilog-Perl is part of the L<http://www.veripool.org/> free Verilog EDA
+Verilog-Perl is part of the L<https://www.veripool.org/> free Verilog EDA
 software tool suite.  The latest version is available from CPAN and from
-L<http://www.veripool.org/verilog-perl>.
+L<https://www.veripool.org/verilog-perl>.
 
 Copyright 2006-2020 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
