@@ -16,7 +16,7 @@ use Cwd;
 ######################################################################
 #### Configuration Section
 
-$VERSION = '3.470';
+$VERSION = '3.472';
 
 # Basenames we should ignore when recursing directories,
 # Because they contain large files of no relevance
@@ -40,6 +40,7 @@ sub new {
 
     my $self = {defines => {},
 		incdir => ['.', ],
+		includes => {},
 		module_dir => ['.', ],
 		libext => ['.v', ],
 		library => [ ],
@@ -335,6 +336,17 @@ sub write_parameters_file {
     $fh->close;
 }
 
+sub includes {
+    my $self = shift;
+    if (@_) {
+	my $from_filename = shift;
+	my $inc_filename = shift;
+	$self->{includes}{$from_filename} ||= [];
+	push @{$self->{includes}{$from_filename}}, $inc_filename;
+    }
+    return $self->{includes};
+}
+
 #######################################################################
 # Utility functions
 
@@ -756,6 +768,13 @@ undefined variables are not substituted nor cause errors.
 Returns reference to list of include directories.  With argument, adds that
 directory.
 
+=item $self->includes
+
+Returns reference to hash of files that included some file, and for each
+hash value a list of files included.  Only relevant after Verilog::Netlist
+processing.  With two arguments, adds an include for the given referencing
+filename to the given include filename.
+
 =item $self->libext
 
 Returns reference to list of library extensions.  With argument, adds that
@@ -791,9 +810,9 @@ Deletes all non-command line definitions, for implementing `undefineall.
 
 =head1 DISTRIBUTION
 
-Verilog-Perl is part of the L<http://www.veripool.org/> free Verilog EDA
+Verilog-Perl is part of the L<https://www.veripool.org/> free Verilog EDA
 software tool suite.  The latest version is available from CPAN and from
-L<http://www.veripool.org/verilog-perl>.
+L<https://www.veripool.org/verilog-perl>.
 
 Copyright 2000-2020 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
