@@ -115,9 +115,9 @@ strings.  Newlines will be preserved in this process.
 
 =head1 DISTRIBUTION
 
-Verilog-Perl is part of the L<http://www.veripool.org/> free Verilog EDA
+Verilog-Perl is part of the L<https://www.veripool.org/> free Verilog EDA
 software tool suite.  The latest version is available from CPAN and from
-L<http://www.veripool.org/verilog-perl>.
+L<https://www.veripool.org/verilog-perl>.
 
 Copyright 2000-2020 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
@@ -135,7 +135,7 @@ L<Verilog::Parser>,
 L<Verilog::ParseSig>,
 L<Verilog::Getopt>
 
-And the L<http://www.veripool.org/verilog-mode>Verilog-Mode package for Emacs.
+And the L<https://www.veripool.org/verilog-mode>Verilog-Mode package for Emacs.
 
 =cut
 ######################################################################
@@ -151,7 +151,7 @@ use Carp;
 ######################################################################
 #### Configuration Section
 
-$VERSION = '3.470';
+$VERSION = '3.472';
 
 ######################################################################
 #### Internal Variables
