@@ -14,7 +14,7 @@ use base qw(Verilog::Netlist::Subclass);
 use strict;
 use vars qw($Debug $Verbose $VERSION);
 
-$VERSION = '3.470';
+$VERSION = '3.472';
 
 ######################################################################
 #### Error Handling
@@ -533,7 +533,7 @@ With synthesis set, define SYNTHESIS, and ignore text between "ambit",
 "pragma", "synopsys" or "synthesis" translate_off and translate_on meta
 comments.  Note using metacomments is discouraged as they have led to
 silicon bugs (versus ifdef SYNTHESIS); see
-L<http://www.veripool.org/papers/TenIPEdits_SNUGBos07_paper.pdf>.
+L<https://www.veripool.org/papers/TenIPEdits_SNUGBos07_paper.pdf>.
 
 =item use_pinselects => $true_or_false
 
@@ -694,9 +694,9 @@ Order based pin interconnect is not supported, use name based connections.
 
 =head1 DISTRIBUTION
 
-Verilog-Perl is part of the L<http://www.veripool.org/> free Verilog EDA
+Verilog-Perl is part of the L<https://www.veripool.org/> free Verilog EDA
 software tool suite.  The latest version is available from CPAN and from
-L<http://www.veripool.org/verilog-perl>.
+L<https://www.veripool.org/verilog-perl>.
 
 Copyright 2000-2020 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
@@ -721,6 +721,6 @@ L<Verilog::Netlist::PinSelection>,
 L<Verilog::Netlist::Port>,
 L<Verilog::Netlist::Subclass>
 
-And the L<http://www.veripool.org/verilog-mode>Verilog-Mode package for Emacs.
+And the L<https://www.veripool.org/verilog-mode>Verilog-Mode package for Emacs.
 
 =cut
