@@ -14,7 +14,7 @@ use base qw(Verilog::Parser);
 ######################################################################
 #### Configuration Section
 
-$VERSION = '3.470';
+$VERSION = '3.472';
 
 our @_Callback_Names = qw(
   attribute
@@ -240,12 +240,6 @@ sub port {
     my $pinnum = shift;
 }
 
-sub ppdefine {
-    my $self = shift;
-    my $defvar = shift;
-    my $definition = shift;
-}
-
 sub program {
     my $self = shift;
     my $kwd = shift;
@@ -467,10 +461,6 @@ made outside the port list.
 If you do not need the pin nor var nor port callbacks, consider the
 "$self->new (... use_vars=>0 ...)"  option to accelerate parsing.
 
-=item $self->ppdefine($defvar, $definition)
-
-This method is called when a preprocessor definition is encountered.
-
 =item $self->program($keyword, $name)
 
 This method is called when a program is defined.
@@ -532,9 +522,9 @@ the contents of 'assign' statements are not parsed.
 
 =head1 DISTRIBUTION
 
-Verilog-Perl is part of the L<http://www.veripool.org/> free Verilog EDA
+Verilog-Perl is part of the L<https://www.veripool.org/> free Verilog EDA
 software tool suite.  The latest version is available from CPAN and from
-L<http://www.veripool.org/verilog-perl>.
+L<https://www.veripool.org/verilog-perl>.
 
 Copyright 2000-2020 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
